#! /usr/bin/env python

# This scripts requires the file glyphlist.txt from Adobe in
# the same directory as this script. It requires one
# parameter--the file with extra kerning pairs. It was used
# with a file where the extra kerning pairs for Greek were
# deleted (it is tested in another file). The output are
# files with hard-coded names kerntest.txt and kerntest-sc.txt
# that contain characters in UTF-8 for testing the kerning
# pairs

import os, sys, string, codecs

# create dictionary with glyphs accessible by PostScript names
glyphs = {}
f = open('glyphlist.txt', "r")
for s in f:
    if s[0] != "#":
        [k, v] = s.strip().split(";")
        if len(v) == 4: # just values 0000--FFFF
            glyphs[k] = unichr(int(v, 16))
f.close()

def glyphtounichar(name):
    if name.find("uni") == 0:
        return unichr(int(name[3:], 16))
    else:
        return glyphs[name]

# create text file with kerning pairs in utf8 for testing
fin = open(sys.argv[1], "r")
fout = codecs.open("kerntest.txt", "w", "utf_8")
# no small caps
i = 0
for s in fin:
    if s.find(".SC") < 0:
        [a, b, c, d] = s.split()
        fout.write(glyphtounichar(b) + glyphtounichar(c))
        i = i + 1
        if i == 25:
            fout.write("\n")
            i = 0
        else:
            fout.write(" ")
fout.close()


# create text file with kerning pairs for small caps in utf8 for testing
fin.seek(0)
fout = codecs.open("kerntest-sc.txt", "w", "utf_8")
i = 0
for s in fin:
    if s.find(".SC") >= 0:
        [a, b, c, d] = s.replace(".SC", "").split()
        fout.write(glyphtounichar(b) + glyphtounichar(c))
        i = i + 1
        if i == 25:
            fout.write("\n")
            i = 0
        else:
            fout.write(" ")
fout.close()
fin.close()
